###########
Permissions
###########


..  module:: cms.models

..  class:: PagePermission


..  data:: ACCESS_PAGE

..  data:: ACCESS_CHILDREN

..  data:: ACCESS_DESCENDANTS

..  data:: ACCESS_PAGE_AND_DESCENDANTS
